#ifndef NT2_INCLUDE_CONSTANTS_MZERO_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MZERO_HPP_INCLUDED

#include <nt2/constant/include/constants/mzero.hpp>

#endif
